Quay API Client
===============

Class for performing Quay API queries. Only the necessary queries have been implemented, though more can be added if required. The full API specification can be found at https://docs.quay.io/api/swagger/

.. py:module:: pubtools._quay.quay_api_client

.. autoclass:: QuayApiClient

   .. automethod:: __init__
   .. automethod:: delete_tag
   .. automethod:: delete_repository
